repo

package
v1.0.9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 18, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package repo provides git repository root discovery helpers.

Index

Constants

This section is empty.

Variables

var ErrRepoNotFound = errors.New("no git repository found")

ErrRepoNotFound is returned when no git repository root can be discovered.

Functions

func DiscoverRoot

func DiscoverRoot(start string) (string, error)

DiscoverRoot resolves the git repository root by walking upward from start.

func DiscoverRootFromCWD

func DiscoverRootFromCWD() (string, error)

DiscoverRootFromCWD resolves the git repository root from the current working directory.

Types

This section is empty.

Jump to