Documentation
¶
Overview ¶
Package repo provides git repository root discovery helpers.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrRepoNotFound = errors.New("no git repository found")
ErrRepoNotFound is returned when no git repository root can be discovered.
Functions ¶
func DiscoverRoot ¶
DiscoverRoot resolves the git repository root by walking upward from start.
func DiscoverRootFromCWD ¶
DiscoverRootFromCWD resolves the git repository root from the current working directory.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.